Struct bma_ts::Monotonic

source ·
pub struct Monotonic(/* private fields */);

Implementations

source

impl Monotonic

source

pub fn abs_diff(self, other: Monotonic) -> Duration

source

pub fn as_secs(self) -> u64

source

pub fn from_secs(value: u64) -> Self

source

pub fn as_secs_f64(self) -> f64

source

pub fn from_secs_f64(value: f64) -> Self

source

pub fn as_secs_f32(self) -> f32

source

pub fn from_secs_f32(value: f32) -> Self

source

pub fn as_micros(self) -> u128

source

pub fn from_micros(value: u64) -> Self

source

pub fn as_millis(self) -> u128

source

pub fn from_millis(value: u64) -> Self

source

pub fn as_nanos(self) -> u128

source

pub fn from_nanos(value: u64) -> Self

source

pub fn as_duration(self) -> Duration

source

impl Monotonic

source

pub fn now() -> Self

On non-UNIX platforms returns time since the first access

Panics

On UNIX platforms will panic if the system monotonic clock is not available

source

pub fn now_rounded() -> Self

Panics

On UNIX platforms will panic if the system monotonic clock is not available

source

pub fn elapsed(&self) -> Duration

source

pub fn duration_since(&self, earlier: Self) -> Duration