pub struct Monotonic(/* private fields */);Implementations
sourceimpl Monotonic
impl Monotonic
pub fn abs_diff(self, other: Monotonic) -> Duration
pub fn as_secs(self) -> u64
pub fn from_secs(value: u64) -> Self
pub fn as_secs_f64(self) -> f64
pub fn from_secs_f64(value: f64) -> Self
pub fn as_secs_f32(self) -> f32
pub fn from_secs_f32(value: f32) -> Self
pub fn as_micros(self) -> u128
pub fn from_micros(value: u64) -> Self
pub fn as_millis(self) -> u128
pub fn from_millis(value: u64) -> Self
pub fn as_nanos(self) -> u128
pub fn from_nanos(value: u64) -> Self
pub fn as_duration(self) -> Duration
sourceimpl Monotonic
impl Monotonic
sourcepub fn now() -> Self
pub fn now() -> Self
On non-UNIX platforms returns time since the first access
Panics
On UNIX platforms will panic if the system monotonic clock is not available
sourcepub fn now_rounded() -> Self
pub fn now_rounded() -> Self
Panics
On UNIX platforms will panic if the system monotonic clock is not available
pub fn elapsed(&self) -> Duration
pub fn duration_since(&self, earlier: Self) -> Duration